import React from 'react';
import { FilterMatchEnum, MenuPositionEnum } from './constants';
import type { DefaultTheme } from 'styled-components';
import type { ReactNode, ReactText, KeyboardEvent, FocusEventHandler } from 'react';
import type { OptionData, PartialDeep, IconRenderer, FocusedOption, SelectedOption, AriaLiveAttribute } from './types';
export declare type Theme = PartialDeep<DefaultTheme>;
export declare type MultiParams = Readonly<{
    selected: SelectedOption[];
    renderOptionLabel: (data: OptionData) => ReactNode;
}>;
export declare type MenuOption = Readonly<{
    label: ReactText;
    value: ReactText;
    data: OptionData;
    isDisabled?: boolean;
    isSelected?: boolean;
}>;
export declare type SelectRef = Readonly<{
    empty: boolean;
    menuOpen: boolean;
    blur: () => void;
    focus: () => void;
    clearValue: () => void;
    toggleMenu: (state?: boolean) => void;
    setValue: (option?: OptionData) => void;
}>;
export declare type SelectProps = Readonly<{
    async?: boolean;
    inputId?: string;
    selectId?: string;
    isMulti?: boolean;
    ariaLabel?: string;
    required?: boolean;
    loadingMsg?: string;
    autoFocus?: boolean;
    isLoading?: boolean;
    isInvalid?: boolean;
    inputDelay?: number;
    themeConfig?: Theme;
    isDisabled?: boolean;
    placeholder?: string;
    menuWidth?: ReactText;
    menuItemSize?: number;
    isClearable?: boolean;
    lazyLoadMenu?: boolean;
    options?: OptionData[];
    isSearchable?: boolean;
    menuMaxHeight?: number;
    loadingNode?: ReactNode;
    ariaLabelledBy?: string;
    clearIcon?: IconRenderer;
    caretIcon?: IconRenderer;
    openMenuOnClick?: boolean;
    openMenuOnFocus?: boolean;
    menuPortalTarget?: Element;
    menuOverscanCount?: number;
    tabSelectsOption?: boolean;
    filterIgnoreCase?: boolean;
    itemKeySelector?: ReactText;
    menuScrollDuration?: number;
    blurInputOnSelect?: boolean;
    closeMenuOnSelect?: boolean;
    isAriaLiveEnabled?: boolean;
    scrollMenuIntoView?: boolean;
    noOptionsMsg?: string | null;
    ariaLive?: AriaLiveAttribute;
    hideSelectedOptions?: boolean;
    filterIgnoreAccents?: boolean;
    backspaceClearsValue?: boolean;
    menuPosition?: MenuPositionEnum;
    filterMatchFrom?: FilterMatchEnum;
    menuItemDirection?: 'ltr' | 'rtl';
    onMenuOpen?: (...args: any[]) => any;
    onMenuClose?: (...args: any[]) => any;
    onInputChange?: (value?: string) => any;
    initialValue?: OptionData | OptionData[];
    onSearchChange?: (value?: string) => any;
    onOptionChange?: (data: OptionData) => any;
    getOptionLabel?: (data: OptionData) => ReactText;
    getOptionValue?: (data: OptionData) => ReactText;
    onInputBlur?: FocusEventHandler<HTMLInputElement>;
    onInputFocus?: FocusEventHandler<HTMLInputElement>;
    renderOptionLabel?: (data: OptionData) => ReactNode;
    getIsOptionDisabled?: (data: OptionData) => boolean;
    getFilterOptionString?: (option: MenuOption) => string;
    renderMultiOptions?: (params: MultiParams) => ReactNode;
    onKeyDown?: (e: KeyboardEvent<HTMLDivElement>, input?: string, focusedOption?: FocusedOption) => any;
}>;
declare const Select: React.ForwardRefExoticComponent<Readonly<{
    async?: boolean | undefined;
    inputId?: string | undefined;
    selectId?: string | undefined;
    isMulti?: boolean | undefined;
    ariaLabel?: string | undefined;
    required?: boolean | undefined;
    loadingMsg?: string | undefined;
    autoFocus?: boolean | undefined;
    isLoading?: boolean | undefined;
    isInvalid?: boolean | undefined;
    inputDelay?: number | undefined;
    themeConfig?: PartialDeep<DefaultTheme> | undefined;
    isDisabled?: boolean | undefined;
    placeholder?: string | undefined;
    menuWidth?: React.ReactText | undefined;
    menuItemSize?: number | undefined;
    isClearable?: boolean | undefined;
    lazyLoadMenu?: boolean | undefined;
    options?: any[] | undefined;
    isSearchable?: boolean | undefined;
    menuMaxHeight?: number | undefined;
    loadingNode?: ReactNode;
    ariaLabelledBy?: string | undefined;
    clearIcon?: IconRenderer;
    caretIcon?: IconRenderer;
    openMenuOnClick?: boolean | undefined;
    openMenuOnFocus?: boolean | undefined;
    menuPortalTarget?: Element | undefined;
    menuOverscanCount?: number | undefined;
    tabSelectsOption?: boolean | undefined;
    filterIgnoreCase?: boolean | undefined;
    itemKeySelector?: React.ReactText | undefined;
    menuScrollDuration?: number | undefined;
    blurInputOnSelect?: boolean | undefined;
    closeMenuOnSelect?: boolean | undefined;
    isAriaLiveEnabled?: boolean | undefined;
    scrollMenuIntoView?: boolean | undefined;
    noOptionsMsg?: string | null | undefined;
    ariaLive?: AriaLiveAttribute | undefined;
    hideSelectedOptions?: boolean | undefined;
    filterIgnoreAccents?: boolean | undefined;
    backspaceClearsValue?: boolean | undefined;
    menuPosition?: MenuPositionEnum | undefined;
    filterMatchFrom?: FilterMatchEnum | undefined;
    menuItemDirection?: "ltr" | "rtl" | undefined;
    onMenuOpen?: ((...args: any[]) => any) | undefined;
    onMenuClose?: ((...args: any[]) => any) | undefined;
    onInputChange?: ((value?: string | undefined) => any) | undefined;
    initialValue?: OptionData | OptionData[];
    onSearchChange?: ((value?: string | undefined) => any) | undefined;
    onOptionChange?: ((data: OptionData) => any) | undefined;
    getOptionLabel?: ((data: OptionData) => ReactText) | undefined;
    getOptionValue?: ((data: OptionData) => ReactText) | undefined;
    onInputBlur?: React.FocusEventHandler<HTMLInputElement> | undefined;
    onInputFocus?: React.FocusEventHandler<HTMLInputElement> | undefined;
    renderOptionLabel?: ((data: OptionData) => ReactNode) | undefined;
    getIsOptionDisabled?: ((data: OptionData) => boolean) | undefined;
    getFilterOptionString?: ((option: MenuOption) => string) | undefined;
    renderMultiOptions?: ((params: MultiParams) => ReactNode) | undefined;
    onKeyDown?: ((e: KeyboardEvent<HTMLDivElement>, input?: string | undefined, focusedOption?: FocusedOption | undefined) => any) | undefined;
}> & React.RefAttributes<Readonly<{
    empty: boolean;
    menuOpen: boolean;
    blur: () => void;
    focus: () => void;
    clearValue: () => void;
    toggleMenu: (state?: boolean | undefined) => void;
    setValue: (option?: OptionData) => void;
}>>>;
export { Select };
