import React, { useMemo, Fragment } from 'react';
import Option from './Option';
import styled from 'styled-components';
import { FixedSizeList } from 'react-window';
import { isArrayWithLength } from '../../utils';
const NoOptionsMsg = styled.div `
  text-align: center;
  color: ${({ theme }) => theme.noOptions.color};
  margin: ${({ theme }) => theme.noOptions.margin};
  padding: ${({ theme }) => theme.noOptions.padding};
  font-size: ${({ theme }) => theme.noOptions.fontSize};
  ${({ theme }) => theme.noOptions.css}
`;
const MenuList = ({ width, height, itemSize, direction, isLoading, loadingMsg, menuOptions, selectOption, noOptionsMsg, overscanCount, itemKeySelector, fixedSizeListRef, renderOptionLabel, focusedOptionIndex }) => {
    const itemData = useMemo(() => ({
        menuOptions,
        selectOption,
        renderOptionLabel,
        focusedOptionIndex
    }), [menuOptions, focusedOptionIndex, selectOption, renderOptionLabel]);
    if (isLoading) {
        return React.createElement(NoOptionsMsg, null, loadingMsg);
    }
    const itemKey = itemKeySelector
        ? (idx, data) => data.menuOptions[idx][itemKeySelector]
        : undefined;
    return (React.createElement(Fragment, null,
        React.createElement(FixedSizeList, { width: width, height: height, itemKey: itemKey, itemSize: itemSize, itemData: itemData, direction: direction, ref: fixedSizeListRef, overscanCount: overscanCount, itemCount: menuOptions.length }, Option),
        !isArrayWithLength(menuOptions) && noOptionsMsg && (React.createElement(NoOptionsMsg, null, noOptionsMsg))));
};
export default MenuList;
